@@ -8,6 +8,7 @@ from PyQt4.QtNetwork import QNetworkRequest, QNetworkAccessManager, QNetworkProx
 import HTMLParser
 from utils.DebugLog import DebugLog, DebugFile
 from model.RideModel import RideModel, Ride
+import version
 
 class Extractor(QtCore.QObject):
    def __init__(self, id):
@@ -15,7 +16,7 @@ class Extractor(QtCore.QObject):
       QtCore.QObject.__init__(self)
 
       self.url = ''
-      self.report = 'http://gerald.fauvelle.free.fr/traintrain/report.php?ttid=%s&error=%s&url=%s'
+      self.report = 'http://gerald.fauvelle.free.fr/traintrain/report.php?version=%s&ttid=%s&error=%s&url=%s'
       
       self.userAgent = 'Firefox/3.5 Maemo Browser 1.7.4.8 RX-51 N900'
       self.urlPerturb = ''
@@ -188,9 +189,10 @@ class Extractor(QtCore.QObject):
       error = ''
       if len(self.listRides)==0:
          DebugFile(self.html, 'html_%s.html'%self.id)
-         error = self.html
+         error = "error"
          
-      requestReport = QNetworkRequest( QtCore.QUrl(self.report%(self.model.ttConf.ttid, error, self.url)) )
+      v = version.appVersion
+      requestReport = QNetworkRequest( QtCore.QUrl(self.report%(v, self.model.ttConf.ttid, error, self.url)) )
       requestReport.setRawHeader("User-Agent", self.userAgent)
       reply = self.manager2.get(requestReport)
       
