@@ -121,13 +121,13 @@ class TableParserRERratp(Extractor, HTMLParser.HTMLParser):
 
       stops = re.findall("missionstation-on.+?>(.+?)<", str(data))
           
-      s = str(self.depart)
-      s = re.sub("([âaàä])",  "a", s)
-      s = re.sub("([éèêeë])", "e", s)
-      s = re.sub("([iîï])",   "i", s)
-      s = re.sub("([uüûù])",  "u", s)
-      s = re.sub("([oôö])",   "o", s)
-      s = re.sub("([\-\s'])", " ", s)
+      s = unicode(self.depart)
+      s = re.sub(u"([âaàä])",  "a", s)
+      s = re.sub(u"([éèêeë])", "e", s)
+      s = re.sub(u"([iîï])",   "i", s)
+      s = re.sub(u"([uüûù])",  "u", s)
+      s = re.sub(u"([oôö])",   "o", s)
+      s = re.sub(u"([\-\s'])", " ", s)
 
       if s in stops:
          DebugLog('   quick MATCH D %s'%s)
