@@ -3,7 +3,7 @@
 
 from DebugLog import DebugLog
 from ConfigParser import ConfigParser
-import sys, sqlite3, os, codecs
+import os, md5, time
 
 class ConfFile:
    def __init__(self, fichier):
@@ -58,7 +58,7 @@ class RidesConfig:
       return [self.rides[k] for k in sorted(self.rides.keys())]
 
    def LastId(self):
-      if len(self.rides)==0:
+      if not len(self.rides):
          return 0
       else:
          strid = sorted(self.rides.keys(), reverse=True)[0]
@@ -84,7 +84,7 @@ class RidesConfig:
          except:
             sens = 0
 
-         if codeDepart and codeArrivee and tec and depart and arrivee:
+         if codeDepart  and tec and depart:
             l = RideConf(ligne, tec, depart, arrivee, codeDepart, codeArrivee, exploitant, direction, sens)
             self.AddRide(l, section)
 
@@ -98,10 +98,8 @@ class RidesConfig:
       if not filename:
          filename = self.filename
 
-      DebugLog("RidesConfig::WriteRides(%s)"%filename)
-
       f = open(filename, 'w')
-      t = ConfigParser()
+      #t = ConfigParser()
       iride=1
 
       DebugLog("nb rides=%d"%len(self.rides.values()))
@@ -117,7 +115,7 @@ class RidesConfig:
          f.write('codeDepart=%s\n'%ride.codeDepart.strip())
          f.write('codeArrivee=%s\n'%ride.codeArrivee.strip())
          f.write('exploitant=%s\n'%ride.exploitant.strip())
-         f.write('sens=%d\n'%ride.sens)
+         f.write('sens=%s\n'%str(ride.sens))
          if ride.direction:
             f.write('direction=%s\n'%ride.direction.strip())
 
@@ -144,7 +142,6 @@ class TrainTrainConf:
       if not os.path.exists(confDir):
          os.makedirs(confDir)
       self.conf = os.path.join(confDir, "traintrain.conf")
-
       self.ReadConfig()
 
    def ReadConfig(self):
@@ -161,6 +158,13 @@ class TrainTrainConf:
             self.refreshrate = t.get('trajets', 'refreshrate')
          except:
             pass
+         try:
+            self.ttid = t.get('trajets', 'ttid')
+         except:
+            m = md5.new()
+            m.update( str(time.time()) )
+            self.ttid = m.hexdigest()
+            self.WriteConfig()
       else:
          self.WriteConfig()
 
@@ -177,6 +181,7 @@ class TrainTrainConf:
       t.add_section('trajets')
       t.set('trajets', 'nbtrains', self.nb)
       t.set('trajets', 'refreshrate', self.refreshrate)
+      t.set('trajets', 'ttid', self.ttid)
       t.write(f)
 
    def nbTrains(self):
