@@ -16,6 +16,9 @@ def DebugFile(msg, filename=''):
    if not filename:
       filename = 'debug.log'
    if os.environ.has_key('DEBUG'):
-      f = open(filename, 'a')
-      f.write(unicode(msg).encode('utf-8'))
-      f.close()
+      try:
+         f = open(filename, 'a')
+         f.write(unicode(msg).encode('utf-8'))
+         f.close()
+      except:
+         pass
