@@ -436,7 +436,7 @@ class AddRideDlg(QtGui.QDialog):
       tec = 'Bus'
       DebugLog('posD=%s, dir=%s'%(codeDepart, str(direction)))
 
-      l = RideConf(str(ligne), tec, str(depart), '', codeDepart, '', 'R', dir, self.sens)
+      l = RideConf(str(ligne), tec, str(depart), str(direction), codeDepart, '', 'R', dir, self.sens)
       if self.garesConf:
          self.garesConf.AddRide(l)
       return l
