@@ -112,7 +112,12 @@ class RideView(QtGui.QWidget):
       iconL.setFixedWidth(44)
       iconL.setStyleSheet("padding-left: 3px ")
       iconPath = self.IconPath('tec/%dx%d/%s%s.png'%(s, s, t, l))
-      iconL.setPixmap( QtGui.QPixmap(iconPath) )
+      if os.path.exists(iconPath):
+         iconL.setPixmap( QtGui.QPixmap(iconPath) )
+      else:
+         self.font.setPointSize(13)
+         iconL.setFont(self.font)
+         iconL.setText(l.replace("B", ""))
       iconLayout.addWidget( iconL, Qt.AlignCenter )
 
       self.layout.setColumnStretch(0, 0)
@@ -128,7 +133,7 @@ class RideView(QtGui.QWidget):
       layoutTitle.setAlignment(Qt.AlignLeft)
       title = QtGui.QPushButton( self.model.getTitle() )
       title.setMinimumHeight(48)
-      self.font.setPointSize(18)
+      self.font.setPointSize(16)
       title.setFont(self.font)
       title.setStyleSheet("QPushButton {\
        background: #fff;\
@@ -208,11 +213,14 @@ class RideView(QtGui.QWidget):
          self.progress.hide()
 
    def Refresh(self):
+      DebugLog("Refresh")
       self.Busy()
       self.parent.model.RefreshDatas(self.model.id)
 
    def RefreshAuto(self):
+      DebugLog("RefreshAuto")
       if not self.timer.isActive():
+         DebugLog("%f sec"%self.parent.model.ttConf.refreshRateSec())
          self.timer.setInterval(self.parent.model.ttConf.refreshRateSec()*1000)
          self.timer.start()
       else:
@@ -222,7 +230,7 @@ class RideView(QtGui.QWidget):
       DebugLog("RideView::UpdateRides %s"%self.model.id)
       irow=2
       height=48
-      self.font.setPointSize(14)
+      self.font.setPointSize(13)
       self.progressIcon.hide()
       self.HideInfo()
 
